@@ -101,8 +101,7 @@ $replaces = array(
 header('Content-type: text/html; charset=utf-8');
 echo '<?xml version="1.0" encoding="utf-8"?'.'>';
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<!DOCTYPE html>
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en" dir="ltr">
 <head>
 <link rel="icon" href="./favicon.ico" type="image/x-icon" />
