@@ -1,8 +1,8 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * @todo    too much die here, or?
- * @package phpMyAdmin
+ * Main export hanling code
+ * @package PhpMyAdmin
  */
 
 /**
@@ -15,14 +15,18 @@ require_once './libraries/plugin_interface.lib.php';
 PMA_checkParameters(array('what', 'export_type'));
 
 // Scan plugins
-$export_list = PMA_getPlugins('./libraries/export/', array('export_type' => $export_type, 'single_table' => isset($single_table)));
+$export_list = PMA_getPlugins(
+    './libraries/export/',
+    array(
+        'export_type' => $export_type,
+        'single_table' => isset($single_table)));
 
 // Backward compatbility
 $type = $what;
 
 // Check export type
-if (!isset($export_list[$type])) {
-    die('Bad type!');
+if (! isset($export_list[$type])) {
+    die(__('Bad type!'));
 }
 
 /**
@@ -31,7 +35,7 @@ if (!isset($export_list[$type])) {
 $compression_methods = array(
     'zip',
     'gzip',
-    'bzip',
+    'bzip2',
 );
 
 /**
@@ -43,7 +47,7 @@ $save_on_server = false;
 $buffer_needed = false;
 
 // Is it a quick or custom export?
-if($_REQUEST['quick_or_custom'] == 'quick') {
+if ($_REQUEST['quick_or_custom'] == 'quick') {
     $quick_export = true;
 } else {
     $quick_export = false;
@@ -58,7 +62,7 @@ if ($_REQUEST['output_format'] == 'astext') {
         $buffer_needed = true;
     }
     if (($quick_export && !empty($_REQUEST['quick_export_onserver'])) || (!$quick_export && !empty($_REQUEST['onserver']))) {
-        if($quick_export) {
+        if ($quick_export) {
             $onserver = $_REQUEST['quick_export_onserver'];
         } else {
             $onserver = $_REQUEST['onserver'];
@@ -71,16 +75,16 @@ if ($_REQUEST['output_format'] == 'astext') {
 // Does export require to be into file?
 if (isset($export_list[$type]['force_file']) && ! $asfile) {
     $message = PMA_Message::error(__('Selected export type has to be saved in file!'));
-    require_once './libraries/header.inc.php';
+    include_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
-        require './server_export.php';
+        include './server_export.php';
     } elseif ($export_type == 'database') {
         $active_page = 'db_export.php';
-        require './db_export.php';
+        include './db_export.php';
     } else {
         $active_page = 'tbl_export.php';
-        require './tbl_export.php';
+        include './tbl_export.php';
     }
     exit();
 }
@@ -99,7 +103,7 @@ if ($export_type == 'server') {
 } elseif ($export_type == 'table' && strlen($db) && strlen($table)) {
     $err_url = 'tbl_export.php?' . PMA_generate_common_url($db, $table);
 } else {
-    die('Bad parameters!');
+    die(__('Bad parameters!'));
 }
 
 // Get the functions specific to the export type
@@ -125,9 +129,8 @@ $time_start = time();
  * Output handler for all exports, if needed buffering, it stores data into
  * $dump_buffer, otherwise it prints thems out.
  *
- * @param   string  the insert statement
- *
- * @return  bool    Whether output suceeded
+ * @param string  $line  the insert statement
+ * @return  bool    Whether output succeeded
  */
 function PMA_exportOutputHandler($line)
 {
@@ -147,14 +150,13 @@ function PMA_exportOutputHandler($line)
 
             if ($dump_buffer_len > $GLOBALS['memory_limit']) {
                 if ($GLOBALS['output_charset_conversion']) {
-                    $dump_buffer = PMA_convert_string($GLOBALS['charset'], $GLOBALS['charset_of_file'], $dump_buffer);
+                    $dump_buffer = PMA_convert_string('utf-8', $GLOBALS['charset_of_file'], $dump_buffer);
                 }
                 // as bzipped
-                if ($GLOBALS['compression'] == 'bzip'  && @function_exists('bzcompress')) {
+                if ($GLOBALS['compression'] == 'bzip2'  && @function_exists('bzcompress')) {
                     $dump_buffer = bzcompress($dump_buffer);
-                }
-                // as a gzipped file
-                elseif ($GLOBALS['compression'] == 'gzip' && @function_exists('gzencode')) {
+                } elseif ($GLOBALS['compression'] == 'gzip' && @function_exists('gzencode')) {
+                    // as a gzipped file
                     // without the optional parameter level because it bug
                     $dump_buffer = gzencode($dump_buffer);
                 }
@@ -181,7 +183,7 @@ function PMA_exportOutputHandler($line)
     } else {
         if ($GLOBALS['asfile']) {
             if ($GLOBALS['output_charset_conversion']) {
-                $line = PMA_convert_string($GLOBALS['charset'], $GLOBALS['charset_of_file'], $line);
+                $line = PMA_convert_string('utf-8', $GLOBALS['charset_of_file'], $line);
             }
             if ($GLOBALS['save_on_server'] && strlen($line) > 0) {
                 $write_result = @fwrite($GLOBALS['file_handle'], $line);
@@ -218,11 +220,11 @@ $output_kanji_conversion = function_exists('PMA_kanji_str_conv') && $type != 'xl
 
 // Do we need to convert charset?
 $output_charset_conversion = $asfile && $GLOBALS['PMA_recoding_engine'] != PMA_CHARSET_NONE
-    && isset($charset_of_file) && $charset_of_file != $charset
+    && isset($charset_of_file) && $charset_of_file != 'utf-8'
     && $type != 'xls';
 
 // Use on the fly compression?
-$onfly_compression = $GLOBALS['cfg']['CompressOnFly'] && ($compression == 'gzip' || $compression == 'bzip');
+$onfly_compression = $GLOBALS['cfg']['CompressOnFly'] && ($compression == 'gzip' || $compression == 'bzip2');
 if ($onfly_compression) {
     $memory_limit = trim(@ini_get('memory_limit'));
     // 2 MB as default
@@ -271,21 +273,23 @@ if ($asfile) {
         }
     }
     $filename = PMA_expandUserString($filename_template);
-    $filename = PMA_sanitize_filename($filename);
+    // remove dots in filename (coming from either the template or already
+    // part of the filename) to avoid a remote code execution vulnerability
+    $filename = PMA_sanitize_filename($filename, $replaceDots = true);
 
     // Grab basic dump extension and mime type
     // Check if the user already added extension; get the substring where the extension would be if it was included
     $extension_start_pos = strlen($filename) - strlen($export_list[$type]['extension']) - 1;
     $user_extension = substr($filename, $extension_start_pos, strlen($filename));
     $required_extension = "." . $export_list[$type]['extension'];
-    if(strtolower($user_extension) != $required_extension) {
+    if (strtolower($user_extension) != $required_extension) {
         $filename  .= $required_extension;
     }
     $mime_type  = $export_list[$type]['mime_type'];
 
     // If dump is going to be compressed, set correct mime_type and add
     // compression to extension
-    if ($compression == 'bzip') {
+    if ($compression == 'bzip2') {
         $filename  .= '.bz2';
         $mime_type = 'application/x-bzip2';
     } elseif ($compression == 'gzip') {
@@ -316,16 +320,16 @@ if ($save_on_server) {
         }
     }
     if (isset($message)) {
-        require_once './libraries/header.inc.php';
+        include_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
-            require './server_export.php';
+            include './server_export.php';
         } elseif ($export_type == 'database') {
             $active_page = 'db_export.php';
-            require './db_export.php';
+            include './db_export.php';
         } else {
             $active_page = 'tbl_export.php';
-            require './tbl_export.php';
+            include './tbl_export.php';
         }
         exit();
     }
@@ -340,42 +344,24 @@ if (!$save_on_server) {
         // Download
         // (avoid rewriting data containing HTML with anchors and forms;
         // this was reported to happen under Plesk)
-        @ini_set('url_rewriter.tags','');
+        @ini_set('url_rewriter.tags', '');
         $filename = PMA_sanitize_filename($filename);
 
-        header('Content-Type: ' . $mime_type);
-        header('Expires: ' . gmdate('D, d M Y H:i:s') . ' GMT');
-        // Tested behavior of
-        //       IE 5.50.4807.2300
-        //       IE 6.0.2800.1106 (small glitch, asks twice when I click Open)
-        //       IE 6.0.2900.2180
-        //       Firefox 1.0.6
-        // in http and https
-        header('Content-Disposition: attachment; filename="' . $filename . '"');
-        if (PMA_USR_BROWSER_AGENT == 'IE') {
-            header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
-            header('Pragma: public');
-        } else {
-            header('Pragma: no-cache');
-            // test case: exporting a database into a .gz file with Safari
-            // would produce files not having the current time
-            // (added this header for Safari but should not harm other browsers)
-            header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
-        }
+        PMA_download_header($filename, $mime_type);
     } else {
         // HTML
         if ($export_type == 'database') {
             $num_tables = count($tables);
             if ($num_tables == 0) {
                 $message = PMA_Message::error(__('No tables found in database.'));
-                require_once './libraries/header.inc.php';
+                include_once './libraries/header.inc.php';
                 $active_page = 'db_export.php';
-                require './db_export.php';
+                include './db_export.php';
                 exit();
             }
         }
         $backup_cfgServer = $cfg['Server'];
-        require_once './libraries/header.inc.php';
+        include_once './libraries/header.inc.php';
         $cfg['Server'] = $backup_cfgServer;
         unset($backup_cfgServer);
         echo "\n" . '<div align="' . $cell_align_left . '">' . "\n";
@@ -394,13 +380,13 @@ if (!$save_on_server) {
         }
 
         // Convert the multiple select elements from an array to a string
-        if($export_type == 'server' && isset($_REQUEST['db_select'])) {
+        if ($export_type == 'server' && isset($_REQUEST['db_select'])) {
             $_REQUEST['db_select'] = implode(",", $_REQUEST['db_select']);
-        } elseif($export_type == 'database' && isset($_REQUEST['table_select'])) {
+        } elseif ($export_type == 'database' && isset($_REQUEST['table_select'])) {
             $_REQUEST['table_select'] = implode(",", $_REQUEST['table_select']);
         }
 
-        foreach($_REQUEST as $name => $value) {
+        foreach ($_REQUEST as $name => $value) {
             $back_button .= '&' . urlencode($name) . '=' . urlencode($value);
         }
         $back_button .= '&repopulate=1">Back</a> ]</p>';
@@ -419,123 +405,182 @@ if (!$save_on_server) {
 // need exceptions here :-)
 do {
 
-// Add possibly some comments to export
-if (!PMA_exportHeader()) {
-    break;
-}
-
-// Will we need relation & co. setup?
-$do_relation = isset($GLOBALS[$what . '_relation']);
-$do_comments = isset($GLOBALS[$what . '_include_comments']);
-$do_mime     = isset($GLOBALS[$what . '_mime']);
-if ($do_relation || $do_comments || $do_mime) {
-    $cfgRelation = PMA_getRelationsParam();
-}
-if ($do_mime) {
-    require_once './libraries/transformations.lib.php';
-}
-
-// Include dates in export?
-$do_dates   = isset($GLOBALS[$what . '_dates']);
-
-/**
- * Builds the dump
- */
-// Gets the number of tables if a dump of a database has been required
-if ($export_type == 'server') {
-    if (isset($db_select)) {
-        $tmp_select = implode($db_select, '|');
-        $tmp_select = '|' . $tmp_select . '|';
-    }
-    // Walk over databases
-    foreach ($GLOBALS['pma']->databases as $current_db) {
-        if ((isset($tmp_select) && strpos(' ' . $tmp_select, '|' . $current_db . '|'))
-            || !isset($tmp_select)) {
-            if (!PMA_exportDBHeader($current_db)) {
-                break 2;
-            }
-            if (!PMA_exportDBCreate($current_db)) {
-                break 2;
-            }
-            if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
-                PMA_exportRoutines($current_db);
-            }
-
-            $tables = PMA_DBI_get_tables($current_db);
-            $views = array();
-            foreach ($tables as $table) {
-                // if this is a view, collect it for later; views must be exported
-                // after the tables
-                $is_view = PMA_Table::isView($current_db, $table);
-                if ($is_view) {
-                    $views[] = $table;
-                }
-                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-                    // for a view, export a stand-in definition of the table
-                    // to resolve view dependencies
-                    if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
-                        break 3;
-                    }
-                }
-                // if this is a view or a merge table, don't export data
-                if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($current_db, $table))) {
-                    $local_query  = 'SELECT * FROM ' . PMA_backquote($current_db) . '.' . PMA_backquote($table);
-                    if (!PMA_exportData($current_db, $table, $crlf, $err_url, $local_query)) {
-                        break 3;
-                    }
-                }
-                // now export the triggers (needs to be done after the data because
-                // triggers can modify already imported tables)
-                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-                    if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
-                        break 2;
-                    }
-                }
-            }
-            foreach($views as $view) {
-                // no data export for a view
-                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-                    if (!PMA_exportStructure($current_db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
-                        break 3;
-                    }
-                }
-            }
-            if (!PMA_exportDBFooter($current_db)) {
-                break 2;
-            }
-        }
-    }
-} elseif ($export_type == 'database') {
-    if (!PMA_exportDBHeader($db)) {
+    // Add possibly some comments to export
+    if (!PMA_exportHeader()) {
         break;
     }
 
-    if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
-            PMA_exportRoutines($db);
+    // Will we need relation & co. setup?
+    $do_relation = isset($GLOBALS[$what . '_relation']);
+    $do_comments = isset($GLOBALS[$what . '_include_comments']);
+    $do_mime     = isset($GLOBALS[$what . '_mime']);
+    if ($do_relation || $do_comments || $do_mime) {
+        $cfgRelation = PMA_getRelationsParam();
+    }
+    if ($do_mime) {
+        include_once './libraries/transformations.lib.php';
     }
 
-    $i = 0;
-    $views = array();
-    // $tables contains the choices from the user (via $table_select)
-    foreach ($tables as $table) {
-        // if this is a view, collect it for later; views must be exported after
-        // the tables
-        $is_view = PMA_Table::isView($db, $table);
-        if ($is_view) {
-            $views[] = $table;
+    // Include dates in export?
+    $do_dates   = isset($GLOBALS[$what . '_dates']);
+
+    /**
+     * Builds the dump
+     */
+    // Gets the number of tables if a dump of a database has been required
+    if ($export_type == 'server') {
+        if (isset($db_select)) {
+            $tmp_select = implode($db_select, '|');
+            $tmp_select = '|' . $tmp_select . '|';
         }
-        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-            // for a view, export a stand-in definition of the table
-            // to resolve view dependencies
-            if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
-                break 2;
+        // Walk over databases
+        foreach ($GLOBALS['pma']->databases as $current_db) {
+            if ((isset($tmp_select) && strpos(' ' . $tmp_select, '|' . $current_db . '|'))
+                || ! isset($tmp_select)) {
+                if (!PMA_exportDBHeader($current_db)) {
+                    break 2;
+                }
+                if (!PMA_exportDBCreate($current_db)) {
+                    break 2;
+                }
+                if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
+                    PMA_exportRoutines($current_db);
+                }
+
+                $tables = PMA_DBI_get_tables($current_db);
+                $views = array();
+                foreach ($tables as $table) {
+                    // if this is a view, collect it for later; views must be exported
+                    // after the tables
+                    $is_view = PMA_Table::isView($current_db, $table);
+                    if ($is_view) {
+                        $views[] = $table;
+                    }
+                    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                        // for a view, export a stand-in definition of the table
+                        // to resolve view dependencies
+                        if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
+                            break 3;
+                        }
+                    }
+                    // if this is a view or a merge table, don't export data
+                    if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($current_db, $table))) {
+                        $local_query  = 'SELECT * FROM ' . PMA_backquote($current_db) . '.' . PMA_backquote($table);
+                        if (!PMA_exportData($current_db, $table, $crlf, $err_url, $local_query)) {
+                            break 3;
+                        }
+                    }
+                    // now export the triggers (needs to be done after the data because
+                    // triggers can modify already imported tables)
+                    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                        if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
+                            break 2;
+                        }
+                    }
+                }
+                foreach ($views as $view) {
+                    // no data export for a view
+                    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                        if (!PMA_exportStructure($current_db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
+                            break 3;
+                        }
+                    }
+                }
+                if (!PMA_exportDBFooter($current_db)) {
+                    break 2;
+                }
             }
         }
-        // if this is a view or a merge table, don't export data
-        if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($db, $table))) {
-            $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table);
+    } elseif ($export_type == 'database') {
+        if (!PMA_exportDBHeader($db)) {
+            break;
+        }
+
+        if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
+            PMA_exportRoutines($db);
+        }
+
+        $i = 0;
+        $views = array();
+        // $tables contains the choices from the user (via $table_select)
+        foreach ($tables as $table) {
+            // if this is a view, collect it for later; views must be exported after
+            // the tables
+            $is_view = PMA_Table::isView($db, $table);
+            if ($is_view) {
+                $views[] = $table;
+            }
+            if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                // for a view, export a stand-in definition of the table
+                // to resolve view dependencies
+                if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
+                    break 2;
+                }
+            }
+            // if this is a view or a merge table, don't export data
+            if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($db, $table))) {
+                $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table);
+                if (!PMA_exportData($db, $table, $crlf, $err_url, $local_query)) {
+                    break 2;
+                }
+            }
+            // now export the triggers (needs to be done after the data because
+            // triggers can modify already imported tables)
+            if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
+                    break 2;
+                }
+            }
+        }
+        foreach ($views as $view) {
+            // no data export for a view
+            if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+                if (!PMA_exportStructure($db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
+                    break 2;
+                }
+            }
+        }
+
+        if (!PMA_exportDBFooter($db)) {
+            break;
+        }
+    } else {
+        if (!PMA_exportDBHeader($db)) {
+            break;
+        }
+        // We export just one table
+        // $allrows comes from the form when "Dump all rows" has been selected
+        if ($allrows == '0' && $limit_to > 0 && $limit_from >= 0) {
+            $add_query  = ' LIMIT '
+                        . (($limit_from > 0) ? $limit_from . ', ' : '')
+                        . $limit_to;
+        } else {
+            $add_query  = '';
+        }
+
+        $is_view = PMA_Table::isView($db, $table);
+        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
+            if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'create_view' : 'create_table', $export_type)) {
+                break;
+            }
+        }
+        // If this is an export of a single view, we have to export data;
+        // for example, a PDF report
+        // if it is a merge table, no data is exported
+        if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && ! PMA_Table::isMerge($db, $table)) {
+            if (!empty($sql_query)) {
+                // only preg_replace if needed
+                if (!empty($add_query)) {
+                    // remove trailing semicolon before adding a LIMIT
+                    $sql_query = preg_replace('%;\s*$%', '', $sql_query);
+                }
+                $local_query = $sql_query . $add_query;
+                PMA_DBI_select_db($db);
+            } else {
+                $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table) . $add_query;
+            }
             if (!PMA_exportData($db, $table, $crlf, $err_url, $local_query)) {
-                break 2;
+                break;
             }
         }
         // now export the triggers (needs to be done after the data because
@@ -545,87 +590,28 @@ if ($export_type == 'server') {
                 break 2;
             }
         }
-    }
-    foreach ($views as $view) {
-        // no data export for a view
-        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-            if (!PMA_exportStructure($db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
-                break 2;
-            }
-        }
-    }
-
-    if (!PMA_exportDBFooter($db)) {
-        break;
-    }
-} else {
-    if (!PMA_exportDBHeader($db)) {
-        break;
-    }
-    // We export just one table
-    // $allrows comes from the form when "Dump all rows" has been selected
-    if ($allrows == '0' && $limit_to > 0 && $limit_from >= 0) {
-        $add_query  = ' LIMIT '
-                    . (($limit_from > 0) ? $limit_from . ', ' : '')
-                    . $limit_to;
-    } else {
-        $add_query  = '';
-    }
-
-    $is_view = PMA_Table::isView($db, $table);
-    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-        if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'create_view' : 'create_table', $export_type)) {
+        if (!PMA_exportDBFooter($db)) {
             break;
         }
     }
-    // If this is an export of a single view, we have to export data;
-    // for example, a PDF report
-    // if it is a merge table, no data is exported
-    if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && ! PMA_Table::isMerge($db, $table)) {
-        if (!empty($sql_query)) {
-            // only preg_replace if needed
-            if (!empty($add_query)) {
-                // remove trailing semicolon before adding a LIMIT
-                $sql_query = preg_replace('%;\s*$%', '', $sql_query);
-            }
-            $local_query = $sql_query . $add_query;
-            PMA_DBI_select_db($db);
-        } else {
-            $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table) . $add_query;
-        }
-        if (!PMA_exportData($db, $table, $crlf, $err_url, $local_query)) {
-            break;
-        }
-    }
-    // now export the triggers (needs to be done after the data because
-    // triggers can modify already imported tables)
-    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
-        if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
-            break 2;
-        }
-    }
-    if (!PMA_exportDBFooter($db)) {
+    if (!PMA_exportFooter()) {
         break;
     }
-}
-if (!PMA_exportFooter()) {
-    break;
-}
 
 } while (false);
 // End of fake loop
 
 if ($save_on_server && isset($message)) {
-    require_once './libraries/header.inc.php';
+    include_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
-        require './server_export.php';
+        include './server_export.php';
     } elseif ($export_type == 'database') {
         $active_page = 'db_export.php';
-        require './db_export.php';
+        include './db_export.php';
     } else {
         $active_page = 'tbl_export.php';
-        require './tbl_export.php';
+        include './tbl_export.php';
     }
     exit();
 }
@@ -636,7 +622,7 @@ if ($save_on_server && isset($message)) {
 if (!empty($asfile)) {
     // Convert the charset if required.
     if ($output_charset_conversion) {
-        $dump_buffer = PMA_convert_string($GLOBALS['charset'], $GLOBALS['charset_of_file'], $dump_buffer);
+        $dump_buffer = PMA_convert_string('utf-8', $GLOBALS['charset_of_file'], $dump_buffer);
     }
 
     // Do the compression
@@ -647,16 +633,21 @@ if (!empty($asfile)) {
             $zipfile -> addFile($dump_buffer, substr($filename, 0, -4));
             $dump_buffer = $zipfile -> file();
         }
-    }
-    // 2. as a bzipped file
-    elseif ($compression == 'bzip') {
+    } elseif ($compression == 'bzip2') {
+        // 2. as a bzipped file
         if (@function_exists('bzcompress')) {
             $dump_buffer = bzcompress($dump_buffer);
         }
-    }
-    // 3. as a gzipped file
-    elseif ($compression == 'gzip') {
-        if (@function_exists('gzencode') && !@ini_get('zlib.output_compression')) {
+    } elseif ($compression == 'gzip') {
+        // 3. as a gzipped file
+        if (@function_exists('gzencode') 
+            && ! @ini_get('zlib.output_compression')
+            // Here, we detect Apache's mod_deflate so we bet that
+            // this module is active for this instance of phpMyAdmin
+            // and therefore, will gzip encode the content
+            && ! (function_exists('apache_get_modules')
+                && in_array('mod_deflate', apache_get_modules()))
+            ) {
             // without the optional parameter level because it bug
             $dump_buffer = gzencode($dump_buffer);
         }
@@ -672,28 +663,26 @@ if (!empty($asfile)) {
             $message = new PMA_Message(__('Dump has been saved to file %s.'), PMA_Message::SUCCESS, $save_filename);
         }
 
-        require_once './libraries/header.inc.php';
+        include_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
-            require_once './server_export.php';
+            include_once './server_export.php';
         } elseif ($export_type == 'database') {
             $active_page = 'db_export.php';
-            require_once './db_export.php';
+            include_once './db_export.php';
         } else {
             $active_page = 'tbl_export.php';
-            require_once './tbl_export.php';
+            include_once './tbl_export.php';
         }
         exit();
     } else {
         echo $dump_buffer;
     }
-}
-/**
- * Displays the dump...
- */
-else {
+} else {
     /**
-     * Close the html tags and add the footers in dump is displayed on screen
+     * Displays the dump...
+     *
+     * Close the html tags and add the footers if dump is displayed on screen
      */
     echo '</textarea>' . "\n"
        . '    </form>' . "\n";
@@ -724,6 +713,6 @@ else {
 //]]>
 </script>
 <?php
-    require './libraries/footer.inc.php';
+    include './libraries/footer.inc.php';
 } // end if
 ?>
