@@ -1,6 +1,5 @@
-var querywindow="",query_to_load="";function addEvent(a,b,c){if(a.attachEvent){a["e"+b+c]=c;a[b+c]=function(){a["e"+b+c](window.event)};a.attachEvent("on"+b,a[b+c])}else a.addEventListener(b,c,false)}function removeEvent(a,b,c){if(a.detachEvent){a.detachEvent("on"+b,a[b+c]);a[b+c]=null}else a.removeEventListener(b,c,false)}
-function getElementsByClassName(a,b,c){var d=[];if(b==null)b=document;if(c==null)c="*";var e=0;c=b.getElementsByTagName(c);var f=c.length;for(i=0;i<f;i++)if(c[i].className.indexOf(a)!=-1){b=","+c[i].className.split(" ").join(",")+",";if(b.indexOf(","+a+",")!=-1){d[e]=c[i];e++}}return d}function setDb(a){if(a!=db){var b=db;db=a;if(window.frame_navigation.document.getElementById(db)==null)refreshNavigation();else{unmarkDbTable(b);markDbTable(db)}refreshQuerywindow()}}
-function setTable(a){if(a!=table){table=a;window.frame_navigation.document.getElementById(db+"."+table)==null&&table!=""&&refreshNavigation();refreshQuerywindow()}}function refreshMain(a){a||(a=db?opendb_url:"main.php");goTo(a+"?server="+encodeURIComponent(server)+"&token="+encodeURIComponent(token)+"&db="+encodeURIComponent(db)+"&table="+encodeURIComponent(table)+"&lang="+encodeURIComponent(lang)+"&collation_connection="+encodeURIComponent(collation_connection),"main")}
+var querywindow="",query_to_load="";function setDb(a){if(a!=db){var b=db;db=a;if(window.frame_navigation.document.getElementById(db)==null)refreshNavigation();else{unmarkDbTable(b);markDbTable(db)}refreshQuerywindow()}}function setTable(a){if(a!=table){table=a;window.frame_navigation.document.getElementById(db+"."+table)==null&&table!=""&&refreshNavigation();refreshQuerywindow()}}
+function refreshMain(a){a||(a=db?opendb_url:"main.php");goTo(a+"?server="+encodeURIComponent(server)+"&token="+encodeURIComponent(token)+"&db="+encodeURIComponent(db)+"&table="+encodeURIComponent(table)+"&lang="+encodeURIComponent(lang)+"&collation_connection="+encodeURIComponent(collation_connection),"main")}
 function refreshNavigation(a){typeof a!=undefined&&a&&window.parent&&window.parent.frame_navigation?window.parent.frame_navigation.location.reload():goTo("navigation.php?server="+encodeURIComponent(server)+"&token="+encodeURIComponent(token)+"&db="+encodeURIComponent(db)+"&table="+encodeURIComponent(table)+"&lang="+encodeURIComponent(lang)+"&collation_connection="+encodeURIComponent(collation_connection))}
 function unmarkDbTable(a,b){var c=window.frame_navigation.document.getElementById(a);c!=null&&$(c).parent().removeClass("marked");c=window.frame_navigation.document.getElementById(a+"."+b);c!=null&&$(c).parent().removeClass("marked")}
 function markDbTable(a,b){var c=window.frame_navigation.document.getElementById(a);if(c!=null){$(c).parent().addClass("marked");c.focus();c.blur()}c=window.frame_navigation.document.getElementById(a+"."+b);if(c!=null){$(c).parent().addClass("marked");c.focus();c.blur()}window.frame_content.focus()}
