@@ -2,22 +2,14 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @author Alexander Rutkowski
- * @version $Id$
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
-/**
- * Gets relation settings
- */
-require_once './libraries/relation.lib.php';
-
 /**
  * This class tracks changes on databases, tables and views.
  * For more information please see phpMyAdmin/Documentation.html
  *
- * @author Alexander Rutkowski <alexander.rutkowski@googlemail.com>
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  *
  * @todo use stristr instead of strstr
  */
@@ -74,13 +66,24 @@ class PMA_Tracker
      */
     static protected $default_tracking_set;
 
+    /**
+     * Flags copied from `tracking` column definition in `pma_tracking` table.
+     * Used for column type conversion in Drizzle.
+     *
+     * @var array
+     */
+    static private $tracking_set_flags = array('UPDATE','REPLACE','INSERT','DELETE','TRUNCATE','CREATE DATABASE',
+            'ALTER DATABASE','DROP DATABASE','CREATE TABLE','ALTER TABLE','RENAME TABLE','DROP TABLE','CREATE INDEX',
+            'DROP INDEX','CREATE VIEW','ALTER VIEW','DROP VIEW');
+
     /**
      * Initializes settings. See phpMyAdmin/Documentation.html.
      *
      * @static
      *
+     * @return nothing
      */
-    static public function init()
+    static protected function init()
     {
         self::$pma_table = PMA_backquote($GLOBALS['cfg']['Server']['pmadb']) .".".
                            PMA_backquote($GLOBALS['cfg']['Server']['tracking']);
@@ -94,15 +97,15 @@ class PMA_Tracker
         self::$default_tracking_set = $GLOBALS['cfg']['Server']['tracking_default_statements'];
 
         self::$version_auto_create = $GLOBALS['cfg']['Server']['tracking_version_auto_create'];
-
     }
 
     /**
-     * Actually enables tracking. This needs to be done after all 
+     * Actually enables tracking. This needs to be done after all
      * underlaying code is initialized.
      *
      * @static
      *
+     * @return nothing
      */
     static public function enable()
     {
@@ -138,45 +141,12 @@ class PMA_Tracker
         }
     }
 
-    /**
-     * Returns a simple DROP TABLE statement.
-     *
-     * @param string $tablename
-     * @return string
-     */
-    static public function getStatementDropTable($tablename)
-    {
-        return 'DROP TABLE IF EXISTS ' . $tablename;
-    }
-
-    /**
-     * Returns a simple DROP VIEW statement.
-     *
-     * @param string $viewname
-     * @return string
-     */
-    static public function getStatementDropView($viewname)
-    {
-        return 'DROP VIEW IF EXISTS ' . $viewname;
-    }
-
-    /**
-     * Returns a simple DROP DATABASE statement.
-     *
-     * @param string $dbname
-     * @return string
-     */
-    static public function getStatementDropDatabase($dbname)
-    {
-        return 'DROP DATABASE IF EXISTS ' . $dbname;
-    }
-
     /**
      * Parses the name of a table from a SQL statement substring.
      *
-     * @static
+     * @param string $string part of SQL statement
      *
-     * @param  string $string      part of SQL statement
+     * @static
      *
      * @return string the name of table
      */
@@ -185,8 +155,7 @@ class PMA_Tracker
         if (strstr($string, '.')) {
             $temp = explode('.', $string);
             $tablename = $temp[1];
-        }
-        else {
+        } else {
             $tablename = $string;
         }
 
@@ -204,10 +173,10 @@ class PMA_Tracker
     /**
      * Gets the tracking status of a table, is it active or deactive ?
      *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
      *
-     * @param  string $dbname      name of database
-     * @param  string $tablename   name of table
+     * @static
      *
      * @return boolean true or false
      */
@@ -225,10 +194,9 @@ class PMA_Tracker
             return false;
         }
 
-        $sql_query =
-        " SELECT tracking_active FROM " . self::$pma_table .
-        " WHERE " . PMA_backquote('db_name') . " = '" . PMA_sqlAddslashes($dbname) . "' " .
-        " AND " . PMA_backquote('table_name') . " = '" . PMA_sqlAddslashes($tablename) . "' " .
+        $sql_query = " SELECT tracking_active FROM " . self::$pma_table .
+        " WHERE db_name = '" . PMA_sqlAddSlashes($dbname) . "' " .
+        " AND table_name = '" . PMA_sqlAddSlashes($tablename) . "' " .
         " ORDER BY version DESC";
 
         $row = PMA_DBI_fetch_array(PMA_query_as_controluser($sql_query));
@@ -256,13 +224,13 @@ class PMA_Tracker
      * Creates tracking version of a table / view
      * (in other words: create a job to track future changes on the table).
      *
-     * @static
+     * @param string $dbname       name of database
+     * @param string $tablename    name of table
+     * @param string $version      version
+     * @param string $tracking_set set of tracking statements
+     * @param bool   $is_view      if table is a view
      *
-     * @param  string $dbname       name of database
-     * @param  string $tablename    name of table
-     * @param  string $version      version
-     * @param  string $tracking_set set of tracking statements
-     * @param  string $is_view      if table is a view
+     * @static
      *
      * @return int result of version insertion
      */
@@ -274,32 +242,23 @@ class PMA_Tracker
             $tracking_set = self::$default_tracking_set;
         }
 
-        require_once './libraries/export/sql.php';
+        include_once './libraries/export/sql.php';
 
         $sql_backquotes = true;
 
         $date = date('Y-m-d H:i:s');
 
         // Get data definition snapshot of table
-        $sql_query = '
-        SHOW FULL COLUMNS FROM ' . PMA_backquote($dbname) . '.' . PMA_backquote($tablename);
 
-        $sql_result = PMA_DBI_query($sql_query);
-
-        while ($row = PMA_DBI_fetch_array($sql_result)) {
-            $columns[] = $row;
+        $columns = PMA_DBI_get_columns($dbname, $tablename, null, true);
+        // int indices to reduce size
+        $columns = array_values($columns);
+        // remove Privileges to reduce size
+        for ($i = 0; $i < count($columns); $i++) {
+            unset($columns[$i]['Privileges']);
         }
 
-        $sql_query = '
-        SHOW INDEX FROM ' . PMA_backquote($dbname) . '.' . PMA_backquote($tablename);
-
-        $sql_result = PMA_DBI_query($sql_query);
-
-        $indexes = array();
-
-        while($row = PMA_DBI_fetch_array($sql_result)) {
-            $indexes[] = $row;
-        }
+        $indexes = PMA_DBI_get_table_indexes($dbname, $tablename);
 
         $snapshot = array('COLUMNS' => $columns, 'INDEXES' => $indexes);
         $snapshot = serialize($snapshot);
@@ -311,13 +270,13 @@ class PMA_Tracker
 
         if (self::$add_drop_table == true && $is_view == false) {
             $create_sql .= self::getLogComment() .
-                           self::getStatementDropTable(PMA_backquote($tablename)) . ";\n";
+                           'DROP TABLE IF EXISTS ' . PMA_backquote($tablename) . ";\n";
 
         }
 
         if (self::$add_drop_view == true && $is_view == true) {
             $create_sql .= self::getLogComment() .
-                           self::getStatementDropView(PMA_backquote($tablename)) . ";\n";
+                           'DROP VIEW IF EXISTS ' . PMA_backquote($tablename) . ";\n";
         }
 
         $create_sql .= self::getLogComment() .
@@ -325,8 +284,7 @@ class PMA_Tracker
 
         // Save version
 
-        $sql_query =
-        "/*NOTRACK*/\n" .
+        $sql_query = "/*NOTRACK*/\n" .
         "INSERT INTO" . self::$pma_table . " (" .
         "db_name, " .
         "table_name, " .
@@ -339,15 +297,15 @@ class PMA_Tracker
         "tracking " .
         ") " .
         "values (
-        '" . PMA_sqlAddslashes($dbname) . "',
-        '" . PMA_sqlAddslashes($tablename) . "',
-        '" . PMA_sqlAddslashes($version) . "',
-        '" . PMA_sqlAddslashes($date) . "',
-        '" . PMA_sqlAddslashes($date) . "',
-        '" . PMA_sqlAddslashes($snapshot) . "',
-        '" . PMA_sqlAddslashes($create_sql) . "',
-        '" . PMA_sqlAddslashes("\n") . "',
-        '" . PMA_sqlAddslashes($tracking_set) . "' )";
+        '" . PMA_sqlAddSlashes($dbname) . "',
+        '" . PMA_sqlAddSlashes($tablename) . "',
+        '" . PMA_sqlAddSlashes($version) . "',
+        '" . PMA_sqlAddSlashes($date) . "',
+        '" . PMA_sqlAddSlashes($date) . "',
+        '" . PMA_sqlAddSlashes($snapshot) . "',
+        '" . PMA_sqlAddSlashes($create_sql) . "',
+        '" . PMA_sqlAddSlashes("\n") . "',
+        '" . PMA_sqlAddSlashes(self::transformTrackingSet($tracking_set)) . "' )";
 
         $result = PMA_query_as_controluser($sql_query);
 
@@ -361,20 +319,19 @@ class PMA_Tracker
 
 
     /**
-     * Removes all tracking data for a table 
+     * Removes all tracking data for a table
+     *
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
      *
      * @static
      *
-     * @param  string $dbname       name of database
-     * @param  string $tablename    name of table 
-     *
      * @return int result of version insertion
      */
     static public function deleteTracking($dbname, $tablename)
     {
-        $sql_query =
-        "/*NOTRACK*/\n" .
-        "DELETE FROM " . self::$pma_table . " WHERE `db_name` = '" . PMA_sqlAddslashes($dbname) . "' AND `table_name` = '" . PMA_sqlAddslashes($tablename) . "'";
+        $sql_query = "/*NOTRACK*/\n" .
+        "DELETE FROM " . self::$pma_table . " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "'";
         $result = PMA_query_as_controluser($sql_query);
 
         return $result;
@@ -384,39 +341,36 @@ class PMA_Tracker
      * Creates tracking version of a database
      * (in other words: create a job to track future changes on the database).
      *
-     * @static
+     * @param string $dbname       name of database
+     * @param string $version      version
+     * @param string $query        query
+     * @param string $tracking_set set of tracking statements
      *
-     * @param  string $dbname       name of database
-     * @param  string $version      version
-     * @param  string $query        query
-     * @param  string $tracking_set set of tracking statements
+     * @static
      *
      * @return int result of version insertion
      */
     static public function createDatabaseVersion($dbname, $version, $query, $tracking_set = 'CREATE DATABASE,ALTER DATABASE,DROP DATABASE')
     {
-        global $sql_backquotes;
-
         $date = date('Y-m-d H:i:s');
 
         if ($tracking_set == '') {
             $tracking_set = self::$default_tracking_set;
         }
 
-        require_once './libraries/export/sql.php';
+        include_once './libraries/export/sql.php';
 
         $create_sql  = "";
 
         if (self::$add_drop_database == true) {
             $create_sql .= self::getLogComment() .
-                           self::getStatementDropDatabase(PMA_backquote($dbname)) . ";\n";
+                           'DROP DATABASE IF EXISTS ' . PMA_backquote($dbname) . ";\n";
         }
 
         $create_sql .= self::getLogComment() . $query;
 
         // Save version
-        $sql_query =
-        "/*NOTRACK*/\n" .
+        $sql_query = "/*NOTRACK*/\n" .
         "INSERT INTO" . self::$pma_table . " (" .
         "db_name, " .
         "table_name, " .
@@ -429,15 +383,15 @@ class PMA_Tracker
         "tracking " .
         ") " .
         "values (
-        '" . PMA_sqlAddslashes($dbname) . "',
-        '" . PMA_sqlAddslashes('') . "',
-        '" . PMA_sqlAddslashes($version) . "',
-        '" . PMA_sqlAddslashes($date) . "',
-        '" . PMA_sqlAddslashes($date) . "',
-        '" . PMA_sqlAddslashes('') . "',
-        '" . PMA_sqlAddslashes($create_sql) . "',
-        '" . PMA_sqlAddslashes("\n") . "',
-        '" . PMA_sqlAddslashes($tracking_set) . "' )";
+        '" . PMA_sqlAddSlashes($dbname) . "',
+        '" . PMA_sqlAddSlashes('') . "',
+        '" . PMA_sqlAddSlashes($version) . "',
+        '" . PMA_sqlAddSlashes($date) . "',
+        '" . PMA_sqlAddSlashes($date) . "',
+        '" . PMA_sqlAddSlashes('') . "',
+        '" . PMA_sqlAddSlashes($create_sql) . "',
+        '" . PMA_sqlAddSlashes("\n") . "',
+        '" . PMA_sqlAddSlashes(self::transformTrackingSet($tracking_set)) . "' )";
 
         $result = PMA_query_as_controluser($sql_query);
 
@@ -449,23 +403,67 @@ class PMA_Tracker
     /**
      * Changes tracking of a table.
      *
-     * @static
+     * @param string  $dbname    name of database
+     * @param string  $tablename name of table
+     * @param string  $version   version
+     * @param integer $new_state the new state of tracking
      *
-     * @param  string $dbname       name of database
-     * @param  string $tablename    name of table
-     * @param  string $version      version
-     * @param  integer $new_state   the new state of tracking 
+     * @static
      *
      * @return int result of SQL query
      */
-    static private function changeTracking($dbname, $tablename, $version, $new_state)
+    static private function _changeTracking($dbname, $tablename, $version, $new_state)
     {
-        $sql_query =
-        " UPDATE " . self::$pma_table .
+        $sql_query = " UPDATE " . self::$pma_table .
         " SET `tracking_active` = '" . $new_state . "' " .
-        " WHERE `db_name` = '" . PMA_sqlAddslashes($dbname) . "' " .
-        " AND `table_name` = '" . PMA_sqlAddslashes($tablename) . "' " .
-        " AND `version` = '" . PMA_sqlAddslashes($version) . "' ";
+        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' " .
+        " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
+
+        $result = PMA_query_as_controluser($sql_query);
+
+        return $result;
+    }
+
+    /**
+     * Changes tracking data of a table.
+     *
+     * @param string       $dbname    name of database
+     * @param string       $tablename name of table
+     * @param string       $version   version
+     * @param string       $type      type of data(DDL || DML)
+     * @param string|array $new_data  the new tracking data
+     *
+     * @static
+     *
+     * @return bool result of change
+     */
+    static public function changeTrackingData($dbname, $tablename, $version, $type, $new_data)
+    {
+        if ($type == 'DDL') {
+            $save_to = 'schema_sql';
+        } elseif ($type == 'DML') {
+            $save_to = 'data_sql';
+        } else {
+            return false;
+        }
+        $date  = date('Y-m-d H:i:s');
+
+        $new_data_processed = '';
+        if (is_array($new_data)) {
+            foreach ($new_data as $data) {
+                $new_data_processed .= '# log ' . $date . ' ' . $data['username']
+                    . PMA_sqlAddSlashes($data['statement']) . "\n";
+            }
+        } else {
+            $new_data_processed = $new_data;
+        }
+
+        $sql_query = " UPDATE " . self::$pma_table .
+        " SET `" . $save_to . "` = '" . $new_data_processed . "' " .
+        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' " .
+        " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
 
         $result = PMA_query_as_controluser($sql_query);
 
@@ -475,34 +473,34 @@ class PMA_Tracker
     /**
      * Activates tracking of a table.
      *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
+     * @param string $version   version
      *
-     * @param  string $dbname       name of database
-     * @param  string $tablename    name of table
-     * @param  string $version      version
+     * @static
      *
      * @return int result of SQL query
      */
     static public function activateTracking($dbname, $tablename, $version)
     {
-        return self::changeTracking($dbname, $tablename, $version, 1); 
+        return self::_changeTracking($dbname, $tablename, $version, 1);
     }
 
 
     /**
      * Deactivates tracking of a table.
      *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
+     * @param string $version   version
      *
-     * @param  string $dbname       name of database
-     * @param  string $tablename    name of table
-     * @param  string $version      version
+     * @static
      *
      * @return int result of SQL query
      */
     static public function deactivateTracking($dbname, $tablename, $version)
     {
-        return self::changeTracking($dbname, $tablename, $version, 0); 
+        return self::_changeTracking($dbname, $tablename, $version, 0);
     }
 
 
@@ -510,43 +508,40 @@ class PMA_Tracker
      * Gets the newest version of a tracking job
      * (in other words: gets the HEAD version).
      *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
+     * @param string $statement tracked statement
      *
-     * @param  string $dbname      name of database
-     * @param  string $tablename   name of table
-     * @param  string $statement   tracked statement
+     * @static
      *
      * @return int (-1 if no version exists | >  0 if a version exists)
      */
     static public function getVersion($dbname, $tablename, $statement = null)
     {
-        $sql_query =
-        " SELECT MAX(version) FROM " . self::$pma_table .
-        " WHERE `db_name` = '" . PMA_sqlAddslashes($dbname) . "' " .
-        " AND `table_name` = '" . PMA_sqlAddslashes($tablename) . "' ";
+        $sql_query = " SELECT MAX(version) FROM " . self::$pma_table .
+        " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
+        " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) . "' ";
 
         if ($statement != "") {
-            $sql_query .= " AND FIND_IN_SET('" . $statement . "',tracking) > 0" ;
+            $sql_query .= PMA_DRIZZLE
+                ? ' AND tracking & ' . self::transformTrackingSet($statement) . ' <> 0'
+                : " AND FIND_IN_SET('" . $statement . "',tracking) > 0" ;
         }
         $row = PMA_DBI_fetch_array(PMA_query_as_controluser($sql_query));
-        if (isset($row[0])) {
-            $version = $row[0];
-        }
-        if (! isset($version)) {
-            $version = -1;
-        }
-        return $version;
+        return isset($row[0])
+            ? $row[0]
+            : -1;
     }
 
 
     /**
      * Gets the record of a tracking job.
      *
-     * @static
+     * @param string $dbname    name of database
+     * @param string $tablename name of table
+     * @param string $version   version number
      *
-     * @param  string $dbname      name of database
-     * @param  string $tablename   name of table
-     * @param  string $version     version number
+     * @static
      *
      * @return mixed record DDM log, DDL log, structure snapshot, tracked statements.
      */
@@ -556,14 +551,14 @@ class PMA_Tracker
             self::init();
         }
         $sql_query = " SELECT * FROM " . self::$pma_table .
-            " WHERE `db_name` = '" . PMA_sqlAddslashes($dbname) . "' ";
+            " WHERE `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' ";
         if (! empty($tablename)) {
-            $sql_query .= " AND `table_name` = '" . PMA_sqlAddslashes($tablename) ."' ";
+            $sql_query .= " AND `table_name` = '" . PMA_sqlAddSlashes($tablename) ."' ";
         }
-        $sql_query .= " AND `version` = '" . PMA_sqlAddslashes($version) ."' ".
-                     " ORDER BY `version` DESC ";
+        $sql_query .= " AND `version` = '" . PMA_sqlAddSlashes($version) ."' ".
+                     " ORDER BY `version` DESC LIMIT 1";
 
-        $mixed = PMA_DBI_fetch_array(PMA_query_as_controluser($sql_query));
+        $mixed = PMA_DBI_fetch_assoc(PMA_query_as_controluser($sql_query));
 
         // Parse log
         $log_schema_entries = explode('# log ',  $mixed['schema_sql']);
@@ -633,7 +628,7 @@ class PMA_Tracker
         }
         $data['ddlog']           = $ddlog;
         $data['dmlog']           = $dmlog;
-        $data['tracking']        = $mixed['tracking'];
+        $data['tracking']        = self::transformTrackingSet($mixed['tracking']);
         $data['schema_snapshot'] = $mixed['schema_snapshot'];
 
         return $data;
@@ -646,12 +641,12 @@ class PMA_Tracker
      *  - type of statement, is it part of DDL or DML ?
      *  - tablename
      *
+     * @param string $query query
+     *
      * @static
      * @todo: using PMA SQL Parser when possible
      * @todo: support multi-table/view drops
      *
-     * @param string $query
-     *
      * @return mixed Array containing identifier, type and tablename.
      *
      */
@@ -671,7 +666,9 @@ class PMA_Tracker
         $query = trim($query, ' -');
 
         $tokens = explode(" ", $query);
-        $tokens = array_map('strtoupper', $tokens);
+        foreach ($tokens as $key => $value) {
+            $tokens[$key] = strtoupper($value);
+        }
 
         // Parse USE statement, need it for SQL dump imports
         if (substr($query, 0, 4) == 'USE ') {
@@ -686,9 +683,10 @@ class PMA_Tracker
         $result['type']         = 'DDL';
 
         // Parse CREATE VIEW statement
-        if (in_array('CREATE', $tokens) == true && 
-           in_array('VIEW', $tokens) == true && 
-           in_array('AS', $tokens) == true) {
+        if (in_array('CREATE', $tokens) == true
+            && in_array('VIEW', $tokens) == true
+            && in_array('AS', $tokens) == true
+        ) {
             $result['identifier'] = 'CREATE VIEW';
 
             $index = array_search('VIEW', $tokens);
@@ -697,10 +695,11 @@ class PMA_Tracker
         }
 
         // Parse ALTER VIEW statement
-        if (in_array('ALTER', $tokens) == true && 
-           in_array('VIEW', $tokens) == true && 
-           in_array('AS', $tokens) == true && 
-           ! isset($result['identifier'])) {
+        if (in_array('ALTER', $tokens) == true
+            && in_array('VIEW', $tokens) == true
+            && in_array('AS', $tokens) == true
+            && ! isset($result['identifier'])
+        ) {
             $result['identifier'] = 'ALTER VIEW';
 
             $index = array_search('VIEW', $tokens);
@@ -715,7 +714,7 @@ class PMA_Tracker
             $prefix  = explode('DROP VIEW ', $query);
             $str = strstr($prefix[1], 'IF EXISTS');
 
-            if ($str == FALSE ) {
+            if ($str == false ) {
                 $str = $prefix[1];
             }
             $result['tablename'] = self::getTableName($str);
@@ -773,18 +772,17 @@ class PMA_Tracker
             $prefix  = explode('DROP TABLE ', $query);
             $str = strstr($prefix[1], 'IF EXISTS');
 
-            if ($str == FALSE ) {
+            if ($str == false ) {
                 $str = $prefix[1];
             }
             $result['tablename'] = self::getTableName($str);
         }
 
         // Parse CREATE INDEX statement
-        if (! isset($result['identifier']) && 
-            (   substr($query, 0, 12) == 'CREATE INDEX' || 
-                substr($query, 0, 19) == 'CREATE UNIQUE INDEX' || 
-                substr($query, 0, 20) == 'CREATE SPATIAL INDEX'
-            )
+        if (! isset($result['identifier'])
+            && (substr($query, 0, 12) == 'CREATE INDEX'
+            || substr($query, 0, 19) == 'CREATE UNIQUE INDEX'
+            || substr($query, 0, 20) == 'CREATE SPATIAL INDEX')
         ) {
              $result['identifier'] = 'CREATE INDEX';
              $prefix = explode('ON ', $query);
@@ -824,7 +822,7 @@ class PMA_Tracker
         }
 
         // Parse INSERT INTO statement
-        if (! isset($result['identifier']) && substr($query, 0, 11 ) == 'INSERT INTO') {
+        if (! isset($result['identifier']) && substr($query, 0, 11) == 'INSERT INTO') {
             $result['identifier'] = 'INSERT';
             $prefix  = explode('INSERT INTO', $query);
             $suffix  = explode('(', $prefix[1]);
@@ -832,7 +830,7 @@ class PMA_Tracker
         }
 
         // Parse DELETE statement
-        if (! isset($result['identifier']) && substr($query, 0, 6 ) == 'DELETE') {
+        if (! isset($result['identifier']) && substr($query, 0, 6) == 'DELETE') {
             $result['identifier'] = 'DELETE';
             $prefix  = explode('FROM ', $query);
             $suffix  = explode(' ', $prefix[1]);
@@ -840,7 +838,7 @@ class PMA_Tracker
         }
 
         // Parse TRUNCATE statement
-        if (! isset($result['identifier']) && substr($query, 0, 8 ) == 'TRUNCATE') {
+        if (! isset($result['identifier']) && substr($query, 0, 8) == 'TRUNCATE') {
             $result['identifier'] = 'TRUNCATE';
             $prefix  = explode('TRUNCATE', $query);
             $result['tablename'] = self::getTableName($prefix[1]);
@@ -853,15 +851,17 @@ class PMA_Tracker
     /**
      * Analyzes a given SQL statement and saves tracking data.
      *
+     * @param string $query a SQL query
      *
      * @static
-     * @param   string $query a SQL query
+     *
+     * @return nothing
      */
     static public function handleQuery($query)
     {
         // If query is marked as untouchable, leave
         if (strstr($query, "/*NOTRACK*/")) {
-            return false;
+            return;
         }
 
         if (! (substr($query, -1) == ';')) {
@@ -875,8 +875,11 @@ class PMA_Tracker
         // $dbname can be empty, for example when coming from Synchronize
         // and this is a query for the remote server
         if (empty($dbname)) {
-            return false;
+            return;
         }
+        // Remove null bytes (preg_replace() is vulnerable in some
+        // PHP versions)
+        $dbname = str_replace("\0", "", $dbname);
 
         // If we found a valid statement
         if (isset($result['identifier'])) {
@@ -884,8 +887,9 @@ class PMA_Tracker
 
             // If version not exists and auto-creation is enabled
             if (self::$version_auto_create == true
-                && self::isTracked($dbname, $result['tablename']) == false 
-                && $version == -1) {
+                && self::isTracked($dbname, $result['tablename']) == false
+                && $version == -1
+            ) {
                 // Create the version
 
                 switch ($result['identifier']) {
@@ -919,15 +923,14 @@ class PMA_Tracker
                 $query = self::getLogComment() . $query ;
 
                 // Mark it as untouchable
-                $sql_query =
-                " /*NOTRACK*/\n" .
+                $sql_query = " /*NOTRACK*/\n" .
                 " UPDATE " . self::$pma_table .
-                " SET " . PMA_backquote($save_to) ." = CONCAT( " . PMA_backquote($save_to) . ",'\n" . PMA_sqlAddslashes($query) . "') ," .
-                " `date_updated` = '" . $date . "' ";
+                " SET " . PMA_backquote($save_to) ." = CONCAT( " . PMA_backquote($save_to) . ",'\n"
+                . PMA_sqlAddSlashes($query) . "') ," . " `date_updated` = '" . $date . "' ";
 
                 // If table was renamed we have to change the tablename attribute in pma_tracking too
                 if ($result['identifier'] == 'RENAME TABLE') {
-                    $sql_query .= ', `table_name` = \'' . PMA_sqlAddslashes($result['tablename_after_rename']) . '\' ';
+                    $sql_query .= ', `table_name` = \'' . PMA_sqlAddSlashes($result['tablename_after_rename']) . '\' ';
                 }
 
                 // Save the tracking information only for
@@ -937,13 +940,65 @@ class PMA_Tracker
                 // we want to track
                 $sql_query .=
                 " WHERE FIND_IN_SET('" . $result['identifier'] . "',tracking) > 0" .
-                " AND `db_name` = '" . PMA_sqlAddslashes($dbname) . "' " .
-                " AND `table_name` = '" . PMA_sqlAddslashes($result['tablename']) . "' " .
-                " AND `version` = '" . PMA_sqlAddslashes($version) . "' ";
+                " AND `db_name` = '" . PMA_sqlAddSlashes($dbname) . "' " .
+                " AND `table_name` = '" . PMA_sqlAddSlashes($result['tablename']) . "' " .
+                " AND `version` = '" . PMA_sqlAddSlashes($version) . "' ";
 
                 $result = PMA_query_as_controluser($sql_query);
             }
         }
     }
+
+    /**
+     * Transforms tracking set for Drizzle, which has no SET type
+     *
+     * Converts int<>string for Drizzle, does nothing for MySQL
+     *
+     * @param int|string $tracking_set
+     * @return int|string
+     */
+    static private function transformTrackingSet($tracking_set)
+    {
+        if (!PMA_DRIZZLE) {
+            return $tracking_set;
+        }
+
+        // init conversion array (key 3 doesn't exist in calculated array)
+        if (isset(self::$tracking_set_flags[3])) {
+            // initialize flags
+            $set = self::$tracking_set_flags;
+            $array = array();
+            for ($i = 0; $i < count($set); $i++) {
+                $flag = 1 << $i;
+                $array[$flag] = $set[$i];
+                $array[$set[$i]] = $flag;
+            }
+            self::$tracking_set_flags = $array;
+        }
+
+        if (is_numeric($tracking_set)) {
+            // int > string conversion
+            $aflags = array();
+            // count/2 - conversion table has both int > string and string > int values
+            for ($i = 0; $i < count(self::$tracking_set_flags)/2; $i++) {
+                $flag = 1 << $i;
+                if ($tracking_set & $flag) {
+                    $aflags[] = self::$tracking_set_flags[$flag];
+                }
+            }
+            $flags = implode(',', $aflags);
+        } else {
+            // string > int conversion
+            $flags = 0;
+            foreach (explode(',', $tracking_set) as $strflag) {
+                if ($strflag == '') {
+                    continue;
+                }
+                $flags |= self::$tracking_set_flags[$strflag];
+            }
+        }
+
+        return $flags;
+    }
 }
 ?>
